@@ -27,15 +27,13 @@ class DbRedisHelper(object):
             )
         else:
             self.connection = StrictRedis(
-                connection_pool=ConnectionPool(
-                    host=settings.redis_host,
-                    port=settings.redis_port,
-                    db=settings.redis_lock_db,
-                    username=settings.redis_username,
-                    password=settings.redis_password,
-                    decode_responses=True,
-                    ssl=True,
-                )
+                host=settings.redis_host,
+                port=settings.redis_port,
+                db=settings.redis_lock_db,
+                username=settings.redis_username,
+                password=settings.redis_password,
+                decode_responses=True,
+                ssl=True,
             )
 
         self.prefix = 'lock'
